@@ -9,7 +9,7 @@ use PYX::Parser;
 use PYX::Utils;
 use Tags::Output::Raw;
 
-our $VERSION = 0.09;
+our $VERSION = 0.10;
 
 # Constructor.
 sub new {
@@ -183,7 +183,7 @@ PYX::SGML::Tags - Processing PYX data or file and write as SGML via Tags.
  my $obj = PYX::SGML::Tags->new(%parameters);
  $obj->parse($pyx, $out);
  $obj->parse_file($input_file, $out);
- $obj->parse_handle($input_file_handler, $out);
+ $obj->parse_handler($input_file_handler, $out);
  $obj->finalize;
 
 =head1 METHODS
@@ -194,8 +194,6 @@ PYX::SGML::Tags - Processing PYX data or file and write as SGML via Tags.
 
 Constructor.
 
-Returns instance of class.
-
 =over 8
 
 =item * C<input_encoding>
@@ -226,6 +224,8 @@ It's required.
 
 =back
 
+Returns instance of class.
+
 =head2 C<parse>
 
  $obj->parse($pyx, $out);
@@ -249,7 +249,7 @@ Returns undef.
 
 =head2 C<parse_handler>
 
- $obj->parse_handle($input_file_handler, $out);
+ $obj->parse_handler($input_file_handler, $out);
 
 Parse PYX handler.
 C<$input_file_handler> handler is decoded by 'input_encoding'.
@@ -415,12 +415,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2011-2022 Michal Josef Špaček
+© 2011-2023 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.09
+0.10
 
 =cut
